@@ -1,6 +1,5 @@
 read.fmridata = function( directory, format, prefix, nimages, dim.image, nii=TRUE )
 {
- 
  fmridata = array(NA, dim=c(dim.image,nimages))
  
  if(format=="Analyze")
@@ -11,7 +10,7 @@ read.fmridata = function( directory, format, prefix, nimages, dim.image, nii=TRU
     if ((i > 9) && (i <= 99)) aux = paste0("00",i,".img") 
     if ((i > 99) && (i <= 999)) aux = paste0("0",i,".img") 
     if (i > 999) aux = paste0(i,".img") 
-    a = f.read.analyze.volume(paste0(directory, "/", prefix, aux))   
+    a = readANALYZE(paste0(directory, "/", prefix, aux))   
     fmridata[,,,i] = a[,,,1]
    }
    return(fmridata) 
@@ -26,16 +25,14 @@ read.fmridata = function( directory, format, prefix, nimages, dim.image, nii=TRU
     if ((i > 9) && (i <= 99)) aux = paste0("00",i,ext) 
     if ((i > 99) && (i <= 999)) aux = paste0("0",i,ext) 
     if (i > 999) aux = paste0(i,ext) 
-    a = f.read.nifti.volume(paste0(directory, "/", prefix, aux))   
-    fmridata[,,,i] = a
+    fmridata[,,,i] = readNIfTI(paste0(directory, "/", prefix, aux)) 
    }
    return(fmridata) 
  }
  
  if(format=="Afni")
  {
-   a = read.AFNI(paste0(directory, "/", prefix))   
-   fmridata = extract.data(a, what="data")
+   fmridata = readAFNI(paste0(directory, "/", prefix))
    return(fmridata) 
  }
  
